==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/cs_cz/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Hledaným kritériím neodpovídají žádné tipy.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.search.heading_summary'] = 'Souhrn';
$lang['AdminTickets.search.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.search.heading_status'] = 'Stav';
$lang['AdminTickets.search.heading_priority'] = 'Priorita';
$lang['AdminTickets.search.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Hledat vstupenky pro "%1$s"';
$lang['AdminTickets.client.no_results'] = 'V současné době nejsou k dispozici žádné tipy s tímto stavem.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.client.heading_summary'] = 'Souhrn';
$lang['AdminTickets.client.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.client.heading_priority'] = 'Priorita';
$lang['AdminTickets.client.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Vstupenky';
$lang['AdminTickets.client.categorylink_createticket'] = 'Otevřený letenkový lístek';
$lang['AdminTickets.client.category_trash'] = 'Odpadkový koš';
$lang['AdminTickets.client.category_closed'] = 'Uzavřeno';
$lang['AdminTickets.client.category_on_hold'] = 'Na počkání';
$lang['AdminTickets.client.category_in_progress'] = 'Probíhá';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Čekáme na odpověď klienta';
$lang['AdminTickets.client.category_open'] = 'Čekáme na odpověď zaměstnanců';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Odebrat soubor';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';
$lang['AdminTickets.reply.staff_title'] = 'Podpůrný personál';
$lang['AdminTickets.reply.system'] = 'Systém';
$lang['AdminTickets.reply.log_date'] = '%1$s od %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Na otázku %1$s %2$s %3$s odpovědělo';
$lang['AdminTickets.reply.refresh_link'] = 'Klikněte pro zobrazení.';
$lang['AdminTickets.reply.refresh'] = 'Objevují se nové odpovědi nebo změny stavu.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Přejít na';
$lang['AdminTickets.reply.field_replysubmit'] = 'Aktualizovat vstupenku';
$lang['AdminTickets.reply.text_add_attachment'] = 'Přidat přílohu';
$lang['AdminTickets.reply.field_attachments'] = 'Přílohy';
$lang['AdminTickets.reply.field_note'] = 'Poznámka';
$lang['AdminTickets.reply.field_reply'] = 'Odpovědět';
$lang['AdminTickets.reply.heading_reply'] = 'Přidat odpověď';
$lang['AdminTickets.reply.text_with_selected'] = 'U vybraných odpovědí proveďte:';
$lang['AdminTickets.reply.text_add_response'] = 'Vložení předdefinované odpovědi';
$lang['AdminTickets.reply.heading_date_added'] = 'Datum otevření';
$lang['AdminTickets.reply.heading_status'] = 'Stav';
$lang['AdminTickets.reply.heading_priority'] = 'Priorita';
$lang['AdminTickets.reply.heading_staff_id'] = 'Přiřazeno k';
$lang['AdminTickets.reply.heading_department'] = 'Oddělení';
$lang['AdminTickets.reply.heading_client'] = 'Klient';
$lang['AdminTickets.reply.heading_summary'] = 'Souhrn';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Vstupenka #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Odebrat soubor';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';
$lang['AdminTickets.add.text_add_response'] = 'Vložení předdefinované odpovědi';
$lang['Admintickets.add.client_placeholder'] = 'ID nebo jméno klienta';
$lang['AdminTickets.add.field_addsubmit'] = 'Otevřený lístek';
$lang['AdminTickets.add.text_add_attachment'] = 'Přidat přílohu';
$lang['AdminTickets.add.field_details'] = 'Podrobnosti na';
$lang['AdminTickets.add.field_attachments'] = 'Přílohy';
$lang['AdminTickets.add.heading_status'] = 'Stav';
$lang['AdminTickets.add.heading_priority'] = 'Priorita';
$lang['AdminTickets.add.heading_staff_id'] = 'Přiřazeno k';
$lang['AdminTickets.add.heading_department'] = 'Oddělení';
$lang['AdminTickets.add.heading_client'] = 'Klient';
$lang['AdminTickets.add.heading_summary'] = 'Souhrn';
$lang['AdminTickets.add.text_no_clients'] = 'Nebyli nalezeni žádní klienti. Zkuste hledat znovu.';
$lang['AdminTickets.add.heading_search_client'] = 'Hledání klienta';
$lang['AdminTickets.add.boxtitle_add'] = 'Otevřený lístek';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Odeslat';
$lang['AdminTickets.index.text_no_tickets'] = 'Nebyly nalezeny žádné otevřené tipy. Zkuste hledat znovu.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Číslo letenky';
$lang['AdminTickets.index.text_to_status'] = 'Změnit na:';
$lang['AdminTickets.index.text_to_client'] = 'Klientovi:';
$lang['AdminTickets.index.text_into_ticket'] = 'Do vstupenky:';
$lang['AdminTickets.index.text_with_selected'] = 'S vybranými vstupenkami proveďte:';
$lang['AdminTickets.index.no_results'] = 'V současné době nejsou k dispozici žádné tipy s tímto stavem.';
$lang['AdminTickets.index.last_reply_by'] = 'podle';
$lang['AdminTickets.index.unassigned'] = 'Nepřidělené';
$lang['AdminTickets.index.field_last_reply'] = 'Poslední odpověď';
$lang['AdminTickets.index.field_assigned_staff'] = 'Přiřazeno k';
$lang['AdminTickets.index.field_summary'] = 'Souhrn';
$lang['AdminTickets.index.field_department_id'] = 'Oddělení';
$lang['AdminTickets.index.field_priority'] = 'Priorita';
$lang['AdminTickets.index.field_ticket_number'] = 'Číslo letenky';
$lang['AdminTickets.index.hours'] = '%1$s hodin';
$lang['AdminTickets.index.hour'] = '1 hodina';
$lang['AdminTickets.index.minutes'] = '%1$s minut';
$lang['AdminTickets.index.any'] = 'Jakýkoli';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Přiřazeno k';
$lang['AdminTickets.index.heading_summary'] = 'Souhrn';
$lang['AdminTickets.index.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.index.heading_priority'] = 'Priorita';
$lang['AdminTickets.index.heading_client'] = 'Klient';
$lang['AdminTickets.index.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Vstupenky';
$lang['AdminTickets.index.categorylink_createticket'] = 'Otevřený lístek';
$lang['AdminTickets.index.category_trash'] = 'Odpadkový koš';
$lang['AdminTickets.index.category_closed'] = 'Uzavřeno';
$lang['AdminTickets.index.category_on_hold'] = 'Na počkání';
$lang['AdminTickets.index.category_in_progress'] = 'Probíhá';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Čekáme na odpověď klienta';
$lang['AdminTickets.index.category_open'] = 'Čekáme na odpověď zaměstnanců';
$lang['AdminTickets.text.unassigned'] = 'Nepřiřazeno';
$lang['AdminTickets.search.page_title'] = 'Výsledky hledání pro "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Správce podpory > Tiket #%1$s';
$lang['AdminTickets.add.page_title'] = 'Správce podpory > Otevřít tiket';
$lang['AdminTickets.index.page_title'] = 'Správce podpory > Tikety';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Zatím nebyli vytvořeni žádní zaměstnanci ani oddělení. Klikněte na %1$s výše pro vytvoření oddělení nebo na %2$s pro přiřazení zaměstnance.';
$lang['AdminTickets.!success.ticket_delete'] = 'Vybrané tipy byly úspěšně smazány.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Vybrané tipy byly úspěšně aktualizovány.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Vybrané tipy byly úspěšně přiřazeny.';
$lang['AdminTickets.!success.ticket_merge'] = 'Vybrané tipy byly úspěšně sloučeny do tipu #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Tiket #%1$s byl úspěšně rozdělen na tiket #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Tiket #%1$s byl úspěšně aktualizován.';
$lang['AdminTickets.!success.ticket_created'] = 'Tiket #%1$s byl úspěšně otevřen.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/cs_cz/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Hledaným kritériím neodpovídají žádné tipy.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.search.heading_summary'] = 'Souhrn';
$lang['AdminTickets.search.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.search.heading_status'] = 'Stav';
$lang['AdminTickets.search.heading_priority'] = 'Priorita';
$lang['AdminTickets.search.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Hledat vstupenky pro "%1$s"';
$lang['AdminTickets.client.no_results'] = 'V současné době nejsou k dispozici žádné tipy s tímto stavem.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.client.heading_summary'] = 'Souhrn';
$lang['AdminTickets.client.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.client.heading_priority'] = 'Priorita';
$lang['AdminTickets.client.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Vstupenky';
$lang['AdminTickets.client.categorylink_createticket'] = 'Otevřený letenkový lístek';
$lang['AdminTickets.client.category_trash'] = 'Odpadkový koš';
$lang['AdminTickets.client.category_closed'] = 'Uzavřeno';
$lang['AdminTickets.client.category_on_hold'] = 'Na počkání';
$lang['AdminTickets.client.category_in_progress'] = 'Probíhá';
$lang['AdminTickets.client.category_awaiting_reply'] = 'Čekáme na odpověď klienta';
$lang['AdminTickets.client.category_open'] = 'Čekáme na odpověď zaměstnanců';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Odebrat soubor';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';
$lang['AdminTickets.reply.staff_title'] = 'Podpůrný personál';
$lang['AdminTickets.reply.system'] = 'Systém';
$lang['AdminTickets.reply.log_date'] = '%1$s od %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'Na otázku %1$s %2$s %3$s odpovědělo';
$lang['AdminTickets.reply.refresh_link'] = 'Klikněte pro zobrazení.';
$lang['AdminTickets.reply.refresh'] = 'Objevují se nové odpovědi nebo změny stavu.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Přejít na';
$lang['AdminTickets.reply.field_replysubmit'] = 'Aktualizovat vstupenku';
$lang['AdminTickets.reply.text_add_attachment'] = 'Přidat přílohu';
$lang['AdminTickets.reply.field_attachments'] = 'Přílohy';
$lang['AdminTickets.reply.field_note'] = 'Poznámka';
$lang['AdminTickets.reply.field_reply'] = 'Odpovědět';
$lang['AdminTickets.reply.heading_reply'] = 'Přidat odpověď';
$lang['AdminTickets.reply.text_with_selected'] = 'U vybraných odpovědí proveďte:';
$lang['AdminTickets.reply.text_add_response'] = 'Vložení předdefinované odpovědi';
$lang['AdminTickets.reply.heading_date_added'] = 'Datum otevření';
$lang['AdminTickets.reply.heading_status'] = 'Stav';
$lang['AdminTickets.reply.heading_priority'] = 'Priorita';
$lang['AdminTickets.reply.heading_staff_id'] = 'Přiřazeno k';
$lang['AdminTickets.reply.heading_department'] = 'Oddělení';
$lang['AdminTickets.reply.heading_client'] = 'Klient';
$lang['AdminTickets.reply.heading_summary'] = 'Souhrn';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Vstupenka #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Odebrat soubor';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';
$lang['AdminTickets.add.text_add_response'] = 'Vložení předdefinované odpovědi';
$lang['Admintickets.add.client_placeholder'] = 'ID nebo jméno klienta';
$lang['AdminTickets.add.field_addsubmit'] = 'Otevřený lístek';
$lang['AdminTickets.add.text_add_attachment'] = 'Přidat přílohu';
$lang['AdminTickets.add.field_details'] = 'Podrobnosti na';
$lang['AdminTickets.add.field_attachments'] = 'Přílohy';
$lang['AdminTickets.add.heading_status'] = 'Stav';
$lang['AdminTickets.add.heading_priority'] = 'Priorita';
$lang['AdminTickets.add.heading_staff_id'] = 'Přiřazeno k';
$lang['AdminTickets.add.heading_department'] = 'Oddělení';
$lang['AdminTickets.add.heading_client'] = 'Klient';
$lang['AdminTickets.add.heading_summary'] = 'Souhrn';
$lang['AdminTickets.add.text_no_clients'] = 'Nebyli nalezeni žádní klienti. Zkuste hledat znovu.';
$lang['AdminTickets.add.heading_search_client'] = 'Hledání klienta';
$lang['AdminTickets.add.boxtitle_add'] = 'Otevřený lístek';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Odeslat';
$lang['AdminTickets.index.text_no_tickets'] = 'Nebyly nalezeny žádné otevřené tipy. Zkuste hledat znovu.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Číslo letenky';
$lang['AdminTickets.index.text_to_status'] = 'Změnit na:';
$lang['AdminTickets.index.text_to_client'] = 'Klientovi:';
$lang['AdminTickets.index.text_into_ticket'] = 'Do vstupenky:';
$lang['AdminTickets.index.text_with_selected'] = 'S vybranými vstupenkami proveďte:';
$lang['AdminTickets.index.no_results'] = 'V současné době nejsou k dispozici žádné tipy s tímto stavem.';
$lang['AdminTickets.index.last_reply_by'] = 'podle';
$lang['AdminTickets.index.unassigned'] = 'Nepřidělené';
$lang['AdminTickets.index.field_last_reply'] = 'Poslední odpověď';
$lang['AdminTickets.index.field_assigned_staff'] = 'Přiřazeno k';
$lang['AdminTickets.index.field_summary'] = 'Souhrn';
$lang['AdminTickets.index.field_department_id'] = 'Oddělení';
$lang['AdminTickets.index.field_priority'] = 'Priorita';
$lang['AdminTickets.index.field_ticket_number'] = 'Číslo letenky';
$lang['AdminTickets.index.hours'] = '%1$s hodin';
$lang['AdminTickets.index.hour'] = '1 hodina';
$lang['AdminTickets.index.minutes'] = '%1$s minut';
$lang['AdminTickets.index.any'] = 'Jakýkoli';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Poslední odpověď';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Přiřazeno k';
$lang['AdminTickets.index.heading_summary'] = 'Souhrn';
$lang['AdminTickets.index.heading_department_name'] = 'Oddělení';
$lang['AdminTickets.index.heading_priority'] = 'Priorita';
$lang['AdminTickets.index.heading_client'] = 'Klient';
$lang['AdminTickets.index.heading_code'] = 'Číslo letenky';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Vstupenky';
$lang['AdminTickets.index.categorylink_createticket'] = 'Otevřený lístek';
$lang['AdminTickets.index.category_trash'] = 'Odpadkový koš';
$lang['AdminTickets.index.category_closed'] = 'Uzavřeno';
$lang['AdminTickets.index.category_on_hold'] = 'Na počkání';
$lang['AdminTickets.index.category_in_progress'] = 'Probíhá';
$lang['AdminTickets.index.category_awaiting_reply'] = 'Čekáme na odpověď klienta';
$lang['AdminTickets.index.category_open'] = 'Čekáme na odpověď zaměstnanců';
$lang['AdminTickets.text.unassigned'] = 'Nepřiřazeno';
$lang['AdminTickets.search.page_title'] = 'Výsledky hledání pro "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Správce podpory > Tiket #%1$s';
$lang['AdminTickets.add.page_title'] = 'Správce podpory > Otevřít tiket';
$lang['AdminTickets.index.page_title'] = 'Správce podpory > Tikety';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Zatím nebyli vytvořeni žádní zaměstnanci ani oddělení. Klikněte na %1$s výše pro vytvoření oddělení nebo na %2$s pro přiřazení zaměstnance.';
$lang['AdminTickets.!success.ticket_delete'] = 'Vybrané tipy byly úspěšně smazány.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Vybrané tipy byly úspěšně aktualizovány.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Vybrané tipy byly úspěšně přiřazeny.';
$lang['AdminTickets.!success.ticket_merge'] = 'Vybrané tipy byly úspěšně sloučeny do tipu #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Tiket #%1$s byl úspěšně rozdělen na tiket #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Tiket #%1$s byl úspěšně aktualizován.';
$lang['AdminTickets.!success.ticket_created'] = 'Tiket #%1$s byl úspěšně otevřen.';
$lang['AdminTickets.reply.text_contacts'] = 'Kontakty, které nebyly vybrány, budou automaticky přidány k tipu, pokud na něj budou reagovat.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Přidat příjemce';
$lang['AdminTickets.reply.heading_contacts'] = 'Kontakty';
$lang['AdminTickets.reply.heading_recipients'] = 'Příjemci';
$lang['AdminTickets.add.text_contacts'] = 'Kontakty, které nebyly vybrány, budou automaticky přidány k tipu, pokud na něj budou reagovat.';
$lang['AdminTickets.add.text_add_recipient'] = 'Přidat příjemce';
$lang['AdminTickets.add.heading_contacts'] = 'Kontakty';
$lang['AdminTickets.add.heading_recipients'] = 'Příjemci';
